@@ -37,7 +37,8 @@ class ActiveResourceMeta(type):
         
         if klass.Meta.parsed_site[0] not in ('http', 'https'):
             raise ActiveResourceException('Only http and https protocols are allowed')
-            
+        
+        klass.Meta.conntype = getattr(httplib, '%sConnection' % klass.Meta.parsed_site[0].upper())
         klass.Meta.host = klass.Meta.parsed_site[1]
         
         if '@' in klass.Meta.parsed_site[1]:
@@ -88,7 +89,7 @@ class ActiveResource(object):
     find = classmethod(find)
     
     def perform_action(self, action, method='GET', **params):
-        status, xml = self.__class__._make_request(self, method, params, action=action)
+        status, xml = self.__class__._make_request(self, method, params, action=action, skip_param_build=True)
         if not str(status[0]).startswith('2'):
             raise ActiveResourceException('%s: %s' % (status, xml))
             
@@ -102,10 +103,8 @@ class ActiveResource(object):
             method = 'PUT'
         else:
             method = 'POST'
-            
-        params = {}
-        for k in self.Meta.changed:
-            params[k] = getattr(self, k)
+        
+        dict([(k, getattr(self, k)) for k in self.Meta.changed])
         status, xml = self.__class__._make_request(obj=self, method=method, params=params)
         
         if not str(status[0]).startswith('2'):
@@ -166,13 +165,13 @@ class ActiveResource(object):
         return obj
     _parse_xml = classmethod(_parse_xml)
     
-    def _make_request(cls, obj=None, method='GET', params={}, headers={}, action=None):        
+    def _make_request(cls, obj=None, method='GET', params={}, headers={}, action=None, skip_param_build=False):
         if cls.Meta.auth and not headers.has_key('Authorization'):
             headers['Authorization'] = cls.Meta.auth
             
         headers["Content-type"] = "application/x-www-form-urlencoded"
         
-        if method != 'GET':
+        if method != 'GET' and not skip_param_build:
             np = {}
             for key, val in params.iteritems():
                 k = '%s[%s]' % (cls.Meta.name, key)
@@ -187,13 +186,8 @@ class ActiveResource(object):
             
         if method == 'GET':
             path += '?%s' % params
-        
-        if cls.Meta.parsed_site[0] == 'https':
-            conntype = httplib.HTTPSConnection
-        else:
-            conntype = httplib.HTTPConnection
             
-        conn = conntype(cls.Meta.host)
+        conn = cls.Meta.conntype(cls.Meta.host)
         conn.request(method, path, params, headers)
         r = conn.getresponse()
         
